@@ -328,7 +328,7 @@ class Update(MethodsInterface):
                                     dv.Get('cl_update_layman_make'),
                                     dv.Get('cl_update_layman_conf'),
                                     prefix=chroot_path)
-                    if repname != "portage":
+                    if repname not in ("portage", "gentoo"):
                         layman.add(repname, url, rpath_orig)
                     if not self._syncRepository(repname, url, rpath, revision,
                                                 cb_progress=self.setProgress,
@@ -367,7 +367,7 @@ class Update(MethodsInterface):
                             dv.Get('cl_update_layman_make'),
                             dv.Get('cl_update_layman_conf'),
                             prefix=chroot_path)
-            if repname != "portage":
+            if repname not in ("portage", "gentoo"):
                 layman.add(repname, url, rpath_orig)
         finally:
             mtime.restore()
@@ -379,7 +379,7 @@ class Update(MethodsInterface):
         """
         Спрятать кэш
         """
-        if name in ("portage",):
+        if name in ("portage", "gentoo"):
             return
         if not name in OverlayOwnCache(self.clVars):
             for cachename in self.metadata_cache_names:
@@ -399,7 +399,7 @@ class Update(MethodsInterface):
         """
         Извлеч кэш
         """
-        if name in ("portage",):
+        if name in ("portage", "gentoo"):
             return
         cachenames = self.metadata_cache_names
         if not name in OverlayOwnCache(self.clVars):
