@@ -190,7 +190,7 @@ class VariableClUpdateRepPath(ReadonlyVariable):
     """
     type = "list"
     mapPath = {'portage': 'usr/portage',
-               'gentoo': '/usr/portage'}
+               'gentoo': 'usr/portage'}
 
     def get(self):
         repPath = self.Get('cl_update_layman_storage')
